#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-Eoa6tp1s2cQ3SPxlBsPi9A
key:                  ghcide-2.3.0.0-Eoa6tp1s2cQ3SPxlBsPi9A
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  535ac9dd1148e2d2050aea869d4114d0
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-Eoa6tp1s2cQ3SPxlBsPi9A
depends:
    Diff-0.5-A74QtznqER993QsREhG7c9 Glob-0.10.2-Je2AFBeMdZrCN8WlVVm2e9
    aeson-2.2.2.0-6c1DCPq2cjw7mSOIGM724W array-0.5.6.0
    async-2.2.6-4Cg1cnm4CwuITQT2ZpqpLR base-4.18.2.1
    base16-bytestring-1.0.2.0-Kn1heJ4eFku33azk8Re0oa binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-4uVw9MDvZ5oAae1xp3bqUp
    co-log-core-0.3.2.6-Ky7pdewrTtRF0xBcnL3uJF containers-0.6.7
    cryptohash-sha1-0.11.101.0-Hxu26Sh76lDE7uR4nMDrN0
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    dependent-map-0.4.0.1-A2Kcsc3qlF5ByBuQTk2B6g
    dependent-sum-0.7.2.0-3Mm7MmWSybb4OHXPTJLJbD directory-1.3.8.5
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    enummapset-0.7.3.0-JDEeBmOjNhSEOuc4I8TLca exceptions-0.10.7
    extra-1.7.16-JQPIVWTyEPVHbx2JMbVQL9 filepath-1.4.300.1
    fingertree-0.1.6.3-5EdGzVy2JWe6ekrJxjnukR
    focus-1.0.3.2-I4kpwGIXljM8nb20qwIqfM ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-FAY8w7lgAepCo18aqWK5vk
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-1nPoLbPVvwR9vEAwe9aJcc
    hashable-1.4.7.0-29C6HO1kEzxKGOntKCwjk4
    hie-bios-0.12.0-1ZG7JxVpAwmKZ3L4vzAhbb
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-LVwl48jIYql5wPtjHJS9ZX
    hls-graph-2.3.0.0-9HTV86GFbt7DwubseqDsg4
    hls-plugin-api-2.3.0.0-7TrHSX8AWar6cYTbqf1BaR
    implicit-hie-0.1.4.0-6r7J1Bj2Qq84pMNZgi26kX
    implicit-hie-cradle-0.5.0.1-2QOEQnq1o4s1T0cLJseNju
    lens-5.3.4-6KV9HDCdZf8JKhnHS7R55U
    list-t-1.0.5.7-7F9b4dStUW5KCwjvcrP1rU
    lsp-2.2.0.0-KwTs0YLLLhs7xPAe9XbIIA
    lsp-types-2.0.2.0-7cSqO6IrOh32v20RLanVd mtl-2.3.1
    opentelemetry-0.8.0-Hy44Fu1mnl99mNJBU8JBHL
    optparse-applicative-0.18.1.0-BxGWYUUmFSvAWQPaHpJkSX
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-H2rJD2WExIbcRy2n74kLf
    prettyprinter-ansi-terminal-1.1.4-17QDQnvgM0PL8GivpLJq8k
    random-1.2.1.3-2gB92M9Bgui9EHhzBvR4Sg
    regex-tdfa-1.3.2.5-7Nq7C1mNc2TFmrQDItVpcQ
    row-types-1.0.1.2-9K9rqgMFXvA1K9wpE5N4qU
    safe-exceptions-0.1.7.4-H7PY7cHPlBiCkugjevNzTr
    sorted-list-0.2.3.1-5TjWmSEdhi2Gz2We4VjKBx
    sqlite-simple-0.4.19.0-2u8PvCK1AcGJyxvlrdpBL1 stm-2.5.1.0
    stm-containers-1.2.1.1-4oXkyO07MkXL0rWdVo33kq
    syb-0.7.3-AsxB5kY1s6JBFiF2Kn9gZL text-2.0.2
    text-rope-0.3-7ueg5ltCm5LGZM5iJVn7fE time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-GGj9GPgXezm8HQgfatElxR
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-Hsa9d2Ja6XgAATZt7ZTK9f
    vector-0.13.2.0-CQhR7DRX3H037jPZymXmiQ

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

